height = [
    'Overall height',
    'Fuselage height',
    'Height',
    'Height (to top of tail)',
    'Height of Aircraft',
    'Vehicle height',
    'Aircraft height'
]

length = [
    'Fuselage length',
    'Overall length',
    'Length',
    'Length of fuselage',
    'Total length',
    'Vehicle length',
    'Aircraft length'
]

width = [
    'Fuselage width',
    'Vehicle width',
    'Width',
    'Aircraft breadth'
]

size = [
    'Vehicle size',
    'Size',
    'Airframe size'
]

length_and_width = [
    'Length and width',
    'Width and Length',
    'Width and length'
]

dimensions = [
    'Dimensions',
]

wingspan = [
    'Wing span',
    'Wings span',
    'Wingspan',
    'Wingspan (full)'
]

passenger_cabin_length = [
    'Passenger cabin length',
]

passenger_cabin_width = [
    'Passenger cabin width',
]

capacity = [
    'Passenger capacity',
    'Capacity'
]

battery_type = [
    'Battery type',
]

battery_capacity = [
    'Battery capacity',
    'Battery Specific Energy'
]

battery_weight = [
    'Battery weight',
]

fuselage_material = [
    'Fuselage material',
    'Fuselage\xa0material'
]

horse_power = [
    'Horse power',
    'Maximum power output ',
    'Power',
    'Propulsion power',
    'Total power'
]

thrust = [
    'Total system thrust',
    'Maximum thrust',
    'Thrust',
    'Top thrust',
    'Average thrust'
]

static_thrust = [
    'Static Thrust',
]

power_to_weight_ratio = [
    'Power to weight ratio',
]

thrust_ratio = [
    'Thrust ratio',
]

wing_loading = [
    'Wing loading',
]

ceiling = [
    'Ceiling',
]

hover_time = [
    'Hover flight time',
    'Hover time',
    'Hovering-only flight time'
]

landing_gear = [
    'Landing gear',
    'Landing gear configuration'
]

mtow = [
    'MTO weight',
    'MTOW',
    'Maximum Takeoff weight',
    'Max Takeoff Weight',
    'Max takeoff weight',
    'Maximum Take-Off Weight (MTOW)',
    'Maximum take off weight',
    'Maximum take-off weight',
    'Maximum takeoff weight',
    'Maximum takeoff weight (MTOW)',
    'Maximum takeoff weight (fully electric)',
    'Maximum takeoff weight (hybrid-electric)',
    'Maximum vertical takeoff weight',
    'Maximum weight',
    'Takeoff weight'
]

mtom = [
    'Maximum take-off mass (MTOM)',
    'Maximum takeoff mass'
]

gross_weight = [
    'Maximum gross weight',
    'Gross weight'
]

empty_weight = [
    'Operating weight empty (OWE)',
    'Total empty weight',
    'Weight of aircraft empty',
    'Empty Weight',
    'Empty weight',
    'Empty weight without batteries',
    'Aircraft empty weight'
]

baggage = [
    'Baggage',
]

weight = [
    'Weight',
]

payload = [
    'Max Payload',
    'Maximum Payload',
    'Maximum cargo load',
    'Maximum cargo weight',
    'Maximum payload',
    'Maximum payload (fully electric)',
    'Maximum payload (hybrid-electric)',
    'Maximum payload at 0-5000 ft (0-1524 m)',
    'Maximum payload at 5000-13000 ft (1524-3962 m)',
    'Maximum payload weight',
    'Maximum payload weight (for the pilot)',
    'Maximum payload piston powertrain',
    'Payload',
    'Payload capabilities',
    'Payload weight',
    'Payload weight range',
    'Typical mission payload weight',
    'Useful load',
    'Vertical takeoff useful load',
    'Estimated maximum payload',
    'Estimated payload'
]

cargo = [
    'Cargo',
    'Cargo capacity',
    'Cargo maximum payload',
    'Cargo weight',
    'Cargo weight load'
]

max_speed = [
    'Max speed',
    'Maximum flight speed',
    'Maximum speed',
    'Maximum speed (approximately)',
    'Maximum speed (level flight)',
    'Maximum speed (piston engine)',
    'Racing speed',
    'Top speed',
    'Estimated maximum speed',
    'Flight maximum speed'
]

speed = [
    'Speed',
    'Flying speed'
]

min_speed = [
    'Minimum Speed',
    'Minimum speed'
]

max_cruise_speed = [
    'Maximum cruise speed',
    'Maximum cruise speed (air)',
    'eVTOL aircraft cruise speed',
    'Flying cruise speed',
    'Flight cruise speed',
    'Flight cruising speed',
    'Expected cruise speed',
    'Fast cruise speed',
    'Cruise speed (hybrid-electric)',
    'Cruise speed (target)',
    'Cruise speed for maximum range',
    'Cruise speed with best range (piston engine)',
    'Cruise speed with turbine engine',
    'Cruising speed (eVTOL)',
    'Cruise speed (air)',
    'Cruise speed (battery packs)',
    'Cruise Speed',
    'Cruise Speed (estimated)',
    'Cruise speed (estimated)',
    'Cruise speed',
    'Cruising speed',
    'Estimated Cruise Speed',
    'Driving cruise speed',
    'Estimate Cruise speed'
]

max_airspeed = [
    'Maximum airspeed',
]

max_altitude = [
    'Maximu altitude',
    'Maximum Altitude',
    'Maximum altitude (hybrid-electric)',
    'Maximum altitude',
    'Maximum altitude (fully electric)',
    'Top altitude',
    'Altitude',
    'Maximum VTOL takeoff altitude'
]

max_cruise_altitude = [
    'Maximum cruise altitude',
    'Normal cruise altitude',
    'Cruise altitude',
    'Cruising altitude',
    'Estimated Cruise altitude',
    'Cruise Altitude'
]

range = [
    'Normal range',
    'Maximum Range',
    'Maximum estimated range',
    'Maximum range',
    'Maximum range (+ 30 min reserve)',
    'Maximum range (hybrid-electric',
    'Maximum range (air)',
    'Maximum range (airborne)',
    'Maximum range (fully electric)',
    'Hybrid-Electric Range',
    'Hybrid-electric range',
    'Range',
    'Range (air)',
    'Range (battery packs)',
    'Range (estimated)',
    'Range (hybrid-electric)',
    'Range for flying',
    'Range hydrogen fuel cells',
    'Typical mission range (+ 30 min reserve)',
    'VTOL maximum range',
    'VTOL range',
    'eVTOL aircraft range',
    'Flying range',
    'Flying length',
    'Flight maximum range',
    'Flight range',
    'Expected range',
    'Estimated Range',
    'Estimated range',
    'All-electric Range',
    'Electric range',
    'Range with batteries',
    'Range with payload',
    'Range with turbine engine'
]

range_without_payload = [
    'Ferry range (Extended range with no passengers or cargo)',
    'Range without payload'
]

rate_of_climb = [
    'Rate of climb',
    'Estimated rate of climb'
]

reverse_time = [
    'Reserve time',
]

number_of_rotors = [
    'Number of rotors',
]

propeller_count = [
    'Propeller Count',
]

operating_temperature = [
    'Operating temperature',
    'Operating temperatures'
]

pilot = [
    'Pilot',
    'Pilot type',
    'Piloting'
]

price = [
    'Pricing',
    'Estimated retail price'
]
